@@ -37,16 +37,20 @@ class ClockSynchronizer(singleton.Singleton):
 
     def _get_sync_cmd(self):
         platform = os_util.get_os()
+        bot_type = os_util.get_octobot_type()
+        if bot_type == commons_enums.OctoBotTypes.DOCKER.value:
+            raise NotImplementedError(bot_type)
         if platform is commons_enums.PlatformsName.WINDOWS:
             # use 2x w32tm /resync as the 1st one often fails
             return "net stop w32time && net start w32time && w32tm /resync & w32tm /resync && w32tm /query /status"
         if platform is commons_enums.PlatformsName.LINUX:
             return "sudo service ntp stop && sudo ntpd -gq && sudo service ntp start"
         if platform is commons_enums.PlatformsName.MAC:
-            raise NotImplementedError
-        raise NotImplementedError
+            raise NotImplementedError(platform.value)
+        raise NotImplementedError("Unidentified platform")
 
     async def _sync_clock(self):
+        # should only be called when the initial _sync_clock worked
         proc = await asyncio.create_subprocess_shell(
             self._get_sync_cmd(),
             stdout=asyncio.subprocess.PIPE,
@@ -57,7 +61,7 @@ class ClockSynchronizer(singleton.Singleton):
             self.logger.info("Successful os clock synchronization")
         else:
             self.logger.warning(
-                f"Error: Time synchronization command exited with {proc.returncode}] "
+                f"Warning: Time synchronization command exited with {proc.returncode}] "
                 f'command: "{self._get_sync_cmd()}"'
             )
         if stdout:
@@ -65,29 +69,42 @@ class ClockSynchronizer(singleton.Singleton):
         if stderr:
             self.logger.debug(f"[stderr] {stderr}")
 
-    async def start(self) -> bool:
-        """
-        Start the clock synchronization loop if possible on this system
-        :return: True if the loop has been started
-        """
+    async def _ensure_clock_synch_availability(self):
         try:
+            # make sure the command is available on this platform
             self._get_sync_cmd()
-        except NotImplementedError:
+        except NotImplementedError as err:
+            self.logger.debug(f"Clock synchronizer: not implemented on {err}.")
+            return False
+        if not os_util.has_admin_rights():
             self.logger.debug(
-                "Disable clock synchronizer: not implemented on this system."
+                "Admin rights are required to synchronize the computer clock"
             )
             return False
-        if os_util.has_admin_rights():
-            self.logger.debug("Starting clock synchronizer")
-            self.sync_job = async_job.AsyncJob(
-                self._sync_clock, execution_interval_delay=self.sync_interval
-            )
-            await self.sync_job.run()
-            return True
-        self.logger.debug(
-            "Clock synch loop disabled: admin rights are required to synchronize the computer clock"
+        try:
+            # make sure the command is usable on this platform
+            await self._sync_clock()
+        except NotImplementedError as err:
+            self.logger.warning(f"Error when synchronizing clock: {err}")
+            return False
+        return True
+
+    async def start(self) -> bool:
+        """
+        Synch the clock and start the clock synchronization loop if possible on this system
+        :return: True if the loop has been started
+        """
+        if not await self._ensure_clock_synch_availability():
+            self.logger.debug("Clock synch loop disabled")
+            return False
+        self.logger.debug("Starting clock synchronizer")
+        self.sync_job = async_job.AsyncJob(
+            self._sync_clock,
+            first_execution_delay=self.sync_interval,
+            execution_interval_delay=self.sync_interval,
         )
-        return False
+        await self.sync_job.run()
+        return True
 
     def stop(self):
         """
